@@ -36,7 +36,7 @@ BuildInnerBreakdownsRecursively <- function(parent.element,elements,metrics,
     
     # check if we are at the lowest level, or if we need to continue deeper
     
-    if(current.recursion.level<length(elements)-1) {
+    if(current.recursion.level<(nrow(elements)-1)) {
       
       # we need to go deeper, so we add this level to the context 
       # and call BuildInnerBreakdownsRecursively again
@@ -73,25 +73,33 @@ BuildInnerBreakdownsRecursively <- function(parent.element,elements,metrics,
       # build our list of elements
       outer.elements <- working.element$name
       names(outer.elements) <- "name"
+
+      # build named elements, with classifications if they exist
+      elements.named <- elements$id
+      for(i in 1:nrow(elements)) {
+        if(nchar(elements[i,]$classification)>0 && !is.na(elements[i,]$classification)) {
+          elements.named[i] <- paste0(elements[i,]$id,": ",elements[i,]$classification)
+        }
+      }
       
       # if we have a valid date range, apply it to all rows
       if(length(date.range)==2){
-        working.elements.breakdown <- data.frame(matrix(ncol=length(elements)+2, nrow=length(outer.elements)))
-        names(working.elements.breakdown) <- append(c("date.start","date.end"),elements)
+        working.elements.breakdown <- data.frame(matrix(ncol=nrow(elements)+2, nrow=length(outer.elements)))
+        names(working.elements.breakdown) <- append(c("date.start","date.end"),elements.named)
         working.elements.breakdown$date.start <- date.range[1]
         working.elements.breakdown$date.end <- date.range[2]   
       } else {
-        working.elements.breakdown <- data.frame(matrix(ncol=length(elements), nrow=length(outer.elements)))
-        names(working.elements.breakdown) <- elements
+        working.elements.breakdown <- data.frame(matrix(ncol=nrow(elements), nrow=length(outer.elements)))
+        names(working.elements.breakdown) <- elements.named
       }
       
       # apply context to all rows
-      for(j in 1:(length(elements)-1)) {
-        working.elements.breakdown[elements[j]] <- context[j]
+      for(j in 1:(nrow(elements)-1)) {
+        working.elements.breakdown[j] <- context[j]
       }
       
       # apply outer element to all rows
-      working.elements.breakdown[elements[j+1]] <- outer.elements
+      working.elements.breakdown[j+1] <- outer.elements
       
       # bind to the accumulator
       temp <- cbind(working.elements.breakdown,working.metrics)
